"""This module is for the translation mapping data of the
following document:

Document file: display_object_and_graphics_base_prop_abstract.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# DisplayObject and GraphicsBase classes base properties abstract": "# DisplayObject と GraphicsBase クラスの基本的な属性の概要",  # noqa
    ##################################################
    "This page explains the `DisplayObject` and `GraphicsBase` classes' each property (such as the x, visible) abstract.": "このページでは`DisplayObject`や`GraphicsBase`の各サブクラスのxやvisibleなどの基本的な属性の概要について説明します。",  # noqa
    ##################################################
    "## What apysc can do in its properties": "## それらの属性でapyscができること",
    ##################################################
    "- You can get/set each property value, such as the x, y, visible.": "- xやy, visibleなどの属性の取得や更新を行うことができます。",  # noqa
    ##################################################
    "## x and y properties": "## x と y 属性",
    ##################################################
    "The x and y properties can get/set the x and y coordinates.": "xとy属性ではXとY座標を更新・取得することができます。",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n    direction: ap.Int\n\n\ndef on_timer(e: ap.TimerEvent, options: RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : RectOptions\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    direction: ap.Int = options["direction"]\n    rectangle.x += direction\n    rectangle.y += direction\n\n    with ap.If(rectangle.x >= 100):\n        direction.value = -1\n        ap.Return()\n\n    with ap.If(rectangle.x <= 50):\n        direction.value = 1\n        ap.Return()\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=200,\n    stage_height=200,\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\ndirection: ap.Int = ap.Int(1)\noptions: RectOptions = {"rectangle": rectangle, "direction": direction}\nap.Timer(on_timer, delay=ap.FPS.FPS_60, options=options).start()\n\nap.save_overall_html(dest_dir_path="do_and_graphics_base_prop_abstract_x_and_y/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n    direction: ap.Int\n\n\ndef on_timer(e: ap.TimerEvent, options: RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : RectOptions\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    direction: ap.Int = options["direction"]\n    rectangle.x += direction\n    rectangle.y += direction\n\n    with ap.If(rectangle.x >= 100):\n        direction.value = -1\n        ap.Return()\n\n    with ap.If(rectangle.x <= 50):\n        direction.value = 1\n        ap.Return()\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=200,\n    stage_height=200,\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\ndirection: ap.Int = ap.Int(1)\noptions: RectOptions = {"rectangle": rectangle, "direction": direction}\nap.Timer(on_timer, delay=ap.FPS.FPS_60, options=options).start()\n\nap.save_overall_html(dest_dir_path="do_and_graphics_base_prop_abstract_x_and_y/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "For more details, please see the following:": "詳細については以下をご確認ください:",
    ##################################################
    "- [DisplayObject class x and y interfaces](display_object_x_and_y.md).": "- [DisplayObject クラスの x と y インターフェイス](jp_display_object_x_and_y.md)",  # noqa
    ##################################################
    "## visible property": "## visible 属性",
    ##################################################
    "The `visible` property can get/set the visibility of an object.": "`visible`属性ではオブジェクトの表示・非表示の属性値を取得・更新することができます。",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n\n\ndef on_timer(e: ap.TimerEvent, options: RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : RectOptions\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.visible = rectangle.visible.not_\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\noptions: RectOptions = {"rectangle": rectangle}\nap.Timer(on_timer, delay=1000, options=options).start()\n\nap.save_overall_html(dest_dir_path="do_and_graphics_base_prop_abstract_visible/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n\n\ndef on_timer(e: ap.TimerEvent, options: RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : RectOptions\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.visible = rectangle.visible.not_\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\noptions: RectOptions = {"rectangle": rectangle}\nap.Timer(on_timer, delay=1000, options=options).start()\n\nap.save_overall_html(dest_dir_path="do_and_graphics_base_prop_abstract_visible/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "For more details, please see the following:": "詳細については以下をご確認ください:",
    ##################################################
    "- [DisplayObject class visible interface](display_object_visible.md).": "- [DisplayObject クラスの visible (表示・非表示) のインターフェイス](jp_display_object_visible.md)",  # noqa
    ##################################################
    "## rotation interfaces": "## 回転の各インターフェイス",
    ##################################################
    "The `rotation_around_center` property, `get_rotation_around_point` method, and `set_rotation_around_point` method can get/set the rotation angle.": "`rotation_around_center`属性、`get_rotation_around_point`メソッド、そして`set_rotation_around_point`メソッドでは回転の角度の値の取得と更新を行うことができます。",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n\n\ndef on_timer(e: ap.TimerEvent, options: RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : RectOptions\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.rotation_around_center += 1\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\noptions: RectOptions = {"rectangle": rectangle}\nap.Timer(on_timer, delay=ap.FPS.FPS_60, options=options).start()\n\nap.save_overall_html(dest_dir_path="do_and_graphics_base_prop_abstract_rotation/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n\n\ndef on_timer(e: ap.TimerEvent, options: RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : RectOptions\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.rotation_around_center += 1\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\noptions: RectOptions = {"rectangle": rectangle}\nap.Timer(on_timer, delay=ap.FPS.FPS_60, options=options).start()\n\nap.save_overall_html(dest_dir_path="do_and_graphics_base_prop_abstract_rotation/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "For more details, please see the following:": "詳細については以下をご確認ください:",
    ##################################################
    "- [GraphicsBase class rotation_around_center interface](graphics_base_rotation_around_center.md)": "- [GraphicsBase クラスの rotation_around_center (中央座標基準の回転) インターフェイス](jp_graphics_base_rotation_around_center.md)",  # noqa
    ##################################################
    "- [GraphicsBase class rotation_around_point interfaces](graphics_base_rotation_around_point.md).": "- [GraphicsBase クラスの rotation_around_point (指定座標基準の回転) の各インターフェイス](jp_graphics_base_rotation_around_point.md)",  # noqa
    ##################################################
    "## scale interfaces": "## 拡縮の各インターフェイス",
    ##################################################
    "The `scale_x_from_center` property, `scale_y_from_center` property, `get_scale_x_from_point` method, `set_scale_x_from_point` method, `get_scale_y_from_point` method, and `set_scale_y_from_point` method can get/set the scale values.": "`scale_x_from_center`属性、`scale_y_from_center`属性、`get_scale_x_from_point`メソッド、`set_scale_x_from_point`メソッド、`get_scale_y_from_point`メソッド、そして`set_scale_y_from_point`メソッドの各インターフェイスでは拡縮の値の取得と更新を行うことができます。",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n    scale_value: ap.Number\n\n\ndef on_timer(e: ap.TimerEvent, options: RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : RectOptions\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    scale_value: ap.Number = options["scale_value"]\n    rectangle.scale_x_from_center += scale_value\n    rectangle.scale_y_from_center += scale_value\n\n    with ap.If(rectangle.scale_x_from_center >= 2.0):\n        scale_value.value = -0.01\n        ap.Return()\n\n    with ap.If(rectangle.scale_y_from_center <= 0.5):\n        scale_value.value = 0.01\n        ap.Return()\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nscale_value: ap.Number = ap.Number(0.01)\noptions: RectOptions = {"rectangle": rectangle, "scale_value": scale_value}\nap.Timer(on_timer, delay=ap.FPS.FPS_60, options=options).start()\n\nap.save_overall_html(dest_dir_path="do_and_graphics_base_prop_abstract_scale/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n    scale_value: ap.Number\n\n\ndef on_timer(e: ap.TimerEvent, options: RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : RectOptions\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    scale_value: ap.Number = options["scale_value"]\n    rectangle.scale_x_from_center += scale_value\n    rectangle.scale_y_from_center += scale_value\n\n    with ap.If(rectangle.scale_x_from_center >= 2.0):\n        scale_value.value = -0.01\n        ap.Return()\n\n    with ap.If(rectangle.scale_y_from_center <= 0.5):\n        scale_value.value = 0.01\n        ap.Return()\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nscale_value: ap.Number = ap.Number(0.01)\noptions: RectOptions = {"rectangle": rectangle, "scale_value": scale_value}\nap.Timer(on_timer, delay=ap.FPS.FPS_60, options=options).start()\n\nap.save_overall_html(dest_dir_path="do_and_graphics_base_prop_abstract_scale/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "For more details, please see the following:": "詳細については以下をご確認ください:",
    ##################################################
    "- [GraphicsBase class scale_from_center interfaces](graphics_base_scale_from_center.md)": "- [GraphicsBase クラスの scale_from_center (中央座標基準の拡縮) の各インターフェイス](jp_graphics_base_scale_from_center.md)",  # noqa
    ##################################################
    "- [GraphicsBase class scale_from_point interfaces](graphics_base_scale_from_point.md).": "- [GraphicsBase クラスの scale_from_point (指定座標基準の拡縮) の各インターフェイス](jp_graphics_base_scale_from_point.md)",  # noqa
    ##################################################
    "## flip properties": "## 反転の各属性",
    ##################################################
    "The `flip_x` and `flip_y` properties can get/set the flip (reflection) setting.": "`flip_x`と`flip_y`の属性では反転の属性値の取得と更新を行うことができます。",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass LineOptions(TypedDict):\n    line: ap.Line\n\n\ndef on_timer(e: ap.TimerEvent, options: LineOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : LineOptions\n        Optional arguments dictionary.\n    """\n    line: ap.Line = options["line"]\n    line.flip_x = line.flip_x.not_\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.line_style(color=ap.Color("#fff"), thickness=5)\nline: ap.Line = sprite.graphics.draw_line(x_start=50, y_start=50, x_end=100, y_end=100)\n\noptions: LineOptions = {"line": line}\nap.Timer(on_timer, delay=1000, options=options).start()\n\nap.save_overall_html(dest_dir_path="do_and_graphics_base_prop_abstract_flip/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass LineOptions(TypedDict):\n    line: ap.Line\n\n\ndef on_timer(e: ap.TimerEvent, options: LineOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : LineOptions\n        Optional arguments dictionary.\n    """\n    line: ap.Line = options["line"]\n    line.flip_x = line.flip_x.not_\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.line_style(color=ap.Color("#fff"), thickness=5)\nline: ap.Line = sprite.graphics.draw_line(x_start=50, y_start=50, x_end=100, y_end=100)\n\noptions: LineOptions = {"line": line}\nap.Timer(on_timer, delay=1000, options=options).start()\n\nap.save_overall_html(dest_dir_path="do_and_graphics_base_prop_abstract_flip/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "For more details, please see the following:": "詳細については以下をご確認ください:",
    ##################################################
    "- [GraphicsBase class flip_x and flip_y interfaces](graphics_base_flip_interfaces.md)": "- [GraphicsBase クラスの flip_x (横軸の反転) と flip_y (縦軸の反転) のインターフェイス](jp_graphics_base_flip_interfaces.md)",  # noqa
    ##################################################
    "## skew properties": "## 歪みの各属性",
    ##################################################
    "The `skew_x` and `skew_y` properties can get/set the skew-value.": "`skew_x`と`skew_y`の各属性では歪みの値を取得・更新することができます。",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n\n\ndef on_timer(e: ap.TimerEvent, options: RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : RectOptions\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.skew_x += 1\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\noptions: RectOptions = {"rectangle": rectangle}\nap.Timer(on_timer, delay=ap.FPS.FPS_60, options=options).start()\n\nap.save_overall_html(dest_dir_path="do_and_graphics_base_prop_abstract_skew/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n\n\ndef on_timer(e: ap.TimerEvent, options: RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : RectOptions\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.skew_x += 1\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\noptions: RectOptions = {"rectangle": rectangle}\nap.Timer(on_timer, delay=ap.FPS.FPS_60, options=options).start()\n\nap.save_overall_html(dest_dir_path="do_and_graphics_base_prop_abstract_skew/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "For more details, please see the following:": "詳細については以下をご確認ください:",
    ##################################################
    "- [GraphicsBase class skew_x and skew_y interfaces](graphics_base_skew.md).": "- [GraphicsBase クラスの skew_x (X軸の歪み) と skew_y (Y軸の歪み) のインターフェイス](jp_graphics_base_skew.md)",  # noqa
    ##################################################
    "## See also": "## 関連資料",
    ##################################################
    "- [DisplayObject class](display_object.md)": "- [DisplayObject クラス](jp_display_object.md)",  # noqa
    ##################################################
    "- [DisplayObject class parent interfaces](display_object_parent.md)": "- [DisplayObjectクラス parent （親要素属性）のインターフェイス](jp_display_object_parent.md)",  # noqa
}



"""The class implementation for the `speaker_notes_off` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialSpeakerNotesOffIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `speaker_notes_off` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0z" fill="none"/><path d="M10.54 11l-.54-.54L7.54 8 6 6.46 2.38 2.84 1.27 1.73 0 3l2.01 2.01L2 22l4-4h9l5.73 5.73L22 22.46 17.54 18l-7-7zM8 14H6v-2h2v2zm-2-3V9l2 2H6zm14-9H4.08L10 7.92V6h8v2h-7.92l1 1H18v2h-4.92l6.99 6.99C21.14 17.95 22 17.08 22 16V4c0-1.1-.9-2-2-2z"/></svg>'  # noqa



"""The mix-in class implementation for the CSS fill-alpha (`opacity`) property.
"""

from apysc._type.attr_linking_mixin import AttrLinkingMixIn
from apysc._type.number import Number


class OpacityCssMixIn(AttrLinkingMixIn):
    _fill_alpha: Number

    def _initialize_fill_alpha(self) -> None:
        """
        Initialize the `_fill_alpha` attribute.
        """
        if hasattr(self, "_fill_alpha"):
            return
        self._fill_alpha = Number(1.0)

    @property
    def fill_alpha(self) -> Number:
        """
        Get a fill-alpha (opacity) value.

        Returns
        -------
        alpha : Number
            A fill-alpha (opacity) value.

        References
        ----------
        - Text fill_alpha property
            - https://simon-ritchie.github.io/apysc/en/text_fill_alpha.html

        Examples
        --------
        >>> import apysc as ap

        >>> stage: ap.Stage = ap.Stage(
        ...     background_color=ap.Color("#333"),
        ...     stage_width=350,
        ...     stage_height=170,
        ...     stage_elem_id="stage",
        ... )
        >>> multi_line_text: ap.MultiLineText = ap.MultiLineText(
        ...     text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "
        ...     "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "
        ...     "Ut enim ad minim veniam",
        ...     width=300,
        ...     font_size=16,
        ...     fill_color=ap.Color("#00aaff"),
        ...     x=25,
        ...     y=25,
        ... )
        >>> multi_line_text.fill_alpha = ap.Number(0.5)
        >>> multi_line_text.fill_alpha
        Number(0.5)
        """
        self._initialize_fill_alpha()
        return self._fill_alpha.copy()

    @fill_alpha.setter
    def fill_alpha(self, value: Number) -> None:
        """
        Set a fill-alpha (opacity) value.

        Parameters
        ----------
        value : Number
            A fill-alpha (opacity) value.

        References
        ----------
        - Text fill_alpha property
            - https://simon-ritchie.github.io/apysc/en/text_fill_alpha.html

        Examples
        --------
        >>> import apysc as ap

        >>> stage: ap.Stage = ap.Stage(
        ...     background_color=ap.Color("#333"),
        ...     stage_width=350,
        ...     stage_height=170,
        ...     stage_elem_id="stage",
        ... )
        >>> multi_line_text: ap.MultiLineText = ap.MultiLineText(
        ...     text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "
        ...     "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "
        ...     "Ut enim ad minim veniam",
        ...     width=300,
        ...     font_size=16,
        ...     fill_color=ap.Color("#00aaff"),
        ...     x=25,
        ...     y=25,
        ... )
        >>> multi_line_text.fill_alpha = ap.Number(0.5)
        >>> multi_line_text.fill_alpha
        Number(0.5)
        """
        from apysc._display.css_interface import CssInterface
        from apysc._validation import display_validation

        self._initialize_fill_alpha()
        interface: CssInterface = display_validation.validate_css_interface(
            instance=self
        )
        self._fill_alpha = value
        interface.set_css(
            name="opacity",
            value=self._fill_alpha.to_string(),
        )

        self._append_applying_new_attr_val_exp(
            new_attr=self._fill_alpha, attr_name="fill_alpha"
        )
        self._append_attr_to_linking_stack(
            attr=self._fill_alpha, attr_name="fill_alpha"
        )



"""The module for the `SvgForeignObjectChild` class.
"""

from typing import Union

from apysc._display.css_mixin import CssMixIn
from apysc._display.display_object import DisplayObject
from apysc._loop.initialize_with_base_value_interface import (
    InitializeWithBaseValueInterface,
)
from apysc._type.revert_mixin import RevertMixIn
from apysc._type.string import String
from apysc._type.variable_name_suffix_mixin import VariableNameSuffixMixIn


class SvgForeignObjectChild(
    CssMixIn,
    DisplayObject,
    VariableNameSuffixMixIn,
    InitializeWithBaseValueInterface,
    RevertMixIn,
):
    _html_str: String

    def __init__(
        self,
        *,
        html_str: Union[str, String],
        variable_name_suffix: str = "",
    ) -> None:
        """
        Class implementation for the SVG's foreignObject child.

        Parameters
        ----------
        html_str : Union[str, String]
            A HTML string.
        variable_name_suffix : str, default ""
            A JavaScript variable name suffix string.
            This setting is sometimes useful for JavaScript debugging.
        """
        from apysc._converter import to_apysc_val_from_builtin
        from apysc._expression import expression_variables_util
        from apysc._expression import var_names

        self._variable_name_suffix = variable_name_suffix
        variable_name: str = expression_variables_util.get_next_variable_name(
            type_name=var_names.SVG_FOREIGN_OBJECT_CHILD,
        )
        super(SvgForeignObjectChild, self).__init__(variable_name=variable_name)

        suffix: str = self._get_attr_or_variable_name_suffix(
            value_identifier="html_str"
        )
        self._html_str = to_apysc_val_from_builtin.get_copied_string_from_builtin_val(
            string=html_str,
            variable_name_suffix=suffix,
        )
        self._append_constructor_expression()

    def _append_constructor_expression(self) -> None:
        """
        Append a constructor expression of the SVG's foreignObject child.
        """
        from apysc._expression import expression_data_util

        expression: str = (
            f"var {self.variable_name} = SVG({self._html_str.variable_name});"
        )
        expression_data_util.append_js_expression(expression=expression)

    @classmethod
    def _initialize_with_base_value(cls) -> "SvgForeignObjectChild":
        """
        Initialize this class with a base value(s).

        Returns
        -------
        instance : SvgForeignObjectChild
            An initialized instance.
        """
        foreign_object_child: SvgForeignObjectChild = SvgForeignObjectChild(html_str="")
        return foreign_object_child

    def _make_snapshot(self, *, snapshot_name: str) -> None:
        """
        Make values' snapshot.

        Parameters
        ----------
        snapshot_name : str
            Target snapshot name.
        """
        if not hasattr(self, "_html_str"):
            return
        if self._snapshot_exists(snapshot_name=snapshot_name):
            return
        self._html_str._run_all_make_snapshot_methods(snapshot_name=snapshot_name)

    def _revert(self, *, snapshot_name: str) -> None:
        """
        Revert values if a snapshot exists.

        Parameters
        ----------
        snapshot_name : str
            Target snapshot name.
        """
        if not hasattr(self, "_html_str"):
            return
        if not self._snapshot_exists(snapshot_name=snapshot_name):
            return
        self._html_str._run_all_revert_methods(snapshot_name=snapshot_name)



"""The class implementation for the `published_with_changes` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialPublishedWithChangesIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `published_with_changes` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><rect fill="none" height="24" width="24"/><path d="M17.66,9.53l-7.07,7.07l-4.24-4.24l1.41-1.41l2.83,2.83l5.66-5.66L17.66,9.53z M4,12c0-2.33,1.02-4.42,2.62-5.88L9,8.5v-6H3 l2.2,2.2C3.24,6.52,2,9.11,2,12c0,5.19,3.95,9.45,9,9.95v-2.02C7.06,19.44,4,16.07,4,12z M22,12c0-5.19-3.95-9.45-9-9.95v2.02 c3.94,0.49,7,3.86,7,7.93c0,2.33-1.02,4.42-2.62,5.88L15,15.5v6h6l-2.2-2.2C20.76,17.48,22,14.89,22,12z"/></svg>'  # noqa



"""The class implementation for the outlined `slow_motion_video` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialSlowMotionVideoOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `slow_motion_video` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M13.05 9.79L10 7.5v9l3.05-2.29L16 12l-2.95-2.21zm0 0L10 7.5v9l3.05-2.29L16 12l-2.95-2.21zm0 0L10 7.5v9l3.05-2.29L16 12l-2.95-2.21zM11 4.07V2.05c-2.01.2-3.84 1-5.32 2.21L7.1 5.69c1.11-.86 2.44-1.44 3.9-1.62zM5.69 7.1L4.26 5.68C3.05 7.16 2.25 8.99 2.05 11h2.02c.18-1.46.76-2.79 1.62-3.9zM4.07 13H2.05c.2 2.01 1 3.84 2.21 5.32l1.43-1.43c-.86-1.1-1.44-2.43-1.62-3.89zm1.61 6.74C7.16 20.95 9 21.75 11 21.95v-2.02c-1.46-.18-2.79-.76-3.9-1.62l-1.42 1.43zM22 12c0 5.16-3.92 9.42-8.95 9.95v-2.02C16.97 19.41 20 16.05 20 12s-3.03-7.41-6.95-7.93V2.05C18.08 2.58 22 6.84 22 12z"/></svg>'  # noqa



"""Class implementation for the math-related interfaces.
"""

from apysc._math.clamp_mixin import ClampMixIn
from apysc._math.max_mixin import MaxMixIn
from apysc._math.min_mixin import MinMixIn
from apysc._math.trunc_mixin import TruncMixIn


class Math(TruncMixIn, MinMixIn, MaxMixIn, ClampMixIn):
    """Class implementation for the math-related interfaces."""



"""Class implementation for the inheritance of each mouse
event mix-ins.
"""

from apysc._event.click_mixin import ClickMixIn
from apysc._event.double_click_mixin import DoubleClickMixIn
from apysc._event.mouse_down_mixin import MouseDownMixIn
from apysc._event.mouse_move_mixin import MouseMoveMixIn
from apysc._event.mouse_out_mixin import MouseOutMixIn
from apysc._event.mouse_over_mixin import MouseOverMixIn
from apysc._event.mouse_up_mixin import MouseUpMixIn


class MouseEventMixIns(
    ClickMixIn,
    DoubleClickMixIn,
    MouseDownMixIn,
    MouseUpMixIn,
    MouseOverMixIn,
    MouseOutMixIn,
    MouseMoveMixIn,
):
    """Class implementation for the inheritance of each mouse
    event mix-ins.
    """



"""The class implementation for the `import_contacts` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialImportContactsIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `import_contacts` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/></g><g><g><g><path d="M17.5,4.5c-1.95,0-4.05,0.4-5.5,1.5c-1.45-1.1-3.55-1.5-5.5-1.5S2.45,4.9,1,6v14.65c0,0.65,0.73,0.45,0.75,0.45 C3.1,20.45,5.05,20,6.5,20c1.95,0,4.05,0.4,5.5,1.5c1.35-0.85,3.8-1.5,5.5-1.5c1.65,0,3.35,0.3,4.75,1.05 C22.66,21.26,23,20.86,23,20.6V6C21.51,4.88,19.37,4.5,17.5,4.5z M21,18.5c-1.1-0.35-2.3-0.5-3.5-0.5c-1.7,0-4.15,0.65-5.5,1.5V8 c1.35-0.85,3.8-1.5,5.5-1.5c1.2,0,2.4,0.15,3.5,0.5V18.5z"/></g></g></g></svg>'  # noqa



"""Class implementation for the enter frame event.
"""

from typing import Generic
from typing import TypeVar

from typing_extensions import final

from apysc._event.event import Event
from apysc._html.debug_mode import add_debug_info_setting
from apysc._type.variable_name_mixin import VariableNameMixIn
from apysc._validation import arg_validation_decos

Target = TypeVar("Target", bound=VariableNameMixIn)


class EnterFrameEvent(Event[Target], Generic[Target]):
    """
    Enter frame event class.
    """

    @final
    @arg_validation_decos.is_variable_name_interface_type(arg_position_index=1)
    @add_debug_info_setting(module_name=__name__)
    def __init__(self, *, this: Target) -> None:
        """
        Enter frame event class.

        Parameters
        ----------
        this : VariableNameMixIn
            An instance which a listening event.
        """
        from apysc._expression import var_names

        super(EnterFrameEvent, self).__init__(
            this=this,
            type_name=var_names.ENTER_FRAME_EVENT,
        )



"""The class implementation for the outlined `dynamic_form` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialDynamicFormOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `dynamic_form` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/><path d="M13,11H4c-1.1,0-2-0.9-2-2V6c0-1.1,0.9-2,2-2h9V11z M4,9h7V6H4V9z M15,20H4c-1.1,0-2-0.9-2-2v-3c0-1.1,0.9-2,2-2h11V20z M4,18h9v-3H4V18z M22,9h-2l2-5h-7v7h2v9L22,9z M4.75,17.25h1.5v-1.5h-1.5V17.25z M4.75,8.25h1.5v-1.5h-1.5V8.25z"/></g></svg>'  # noqa



"""The class implementation for the outlined `vpn_key` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialVpnKeyOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `vpn_key` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M22 19h-6v-4h-2.68c-1.14 2.42-3.6 4-6.32 4-3.86 0-7-3.14-7-7s3.14-7 7-7c2.72 0 5.17 1.58 6.32 4H24v6h-2v4zm-4-2h2v-4h2v-2H11.94l-.23-.67C11.01 8.34 9.11 7 7 7c-2.76 0-5 2.24-5 5s2.24 5 5 5c2.11 0 4.01-1.34 4.71-3.33l.23-.67H18v4zM7 15c-1.65 0-3-1.35-3-3s1.35-3 3-3 3 1.35 3 3-1.35 3-3 3zm0-4c-.55 0-1 .45-1 1s.45 1 1 1 1-.45 1-1-.45-1-1-1z"/></svg>'  # noqa



"""This module is for the translation mapping data of the
following document:

Document file: graphics_base_rotation_around_point.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# GraphicsBase rotation_around_point interfaces": "# GraphicsBase クラスの rotation_around_point インターフェイス",  # noqa
    ##################################################
    "This page explains the `GraphicsBase` class (base class of each graphic, such as the `Rectangle`) `get_rotation_around_point` and `set_rotation_around_point` method interfaces.": "このページでは`GraphicsBase`クラス（`Rectangle`などの各グラフィックスクラスの基底クラス）の`get_rotation_around_point`と`set_rotation_around_point`の各メソッドのインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interfaces are these?": "## 各インターフェイスの概要",
    ##################################################
    "The `get_rotation_around_point` method will return a rotation value around the given coordinates, and the `set_rotation_around_point` method will update a rotation value around the given coordinates.": "`get_rotation_around_point`メソッドは指定された座標基準の回転量を取得し、`set_rotation_around_point`メソッドは指定された座標を基準とした回転量を更新します。",  # noqa
    ##################################################
    "These rotation values are relative, and each point has the rotation value. For example, the coordinates of the `(x=50, y=50)` and the other coordinates of the `(x=100, y=100)` have different rotation values.": "これらの回転量は相対値であり、各回転量は座標ごとに異なる値が保持されます。例えばx=50, y=50の座標とx=100, y=100の座標の回転量の値はそれぞれ別の値になります。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `get_rotation_around_point` method requires the `x` and `y` arguments and return a rotation value around the given coordinates. The `set_rotation_around_point` requires `x`, `y` and `rotation` arguments. All the arguments and return value are `Int` type.": "`get_rotation_around_point`メソッドは`x`と`y`の引数の指定を必要とし、指定された座標での回転量を返却します。`set_rotation_around_point`メソッドは`x`と`y`、そして`rotation`の引数の指定を必要とします。全ての引数と返却値は`Int`型になります。",  # noqa
    ##################################################
    "The following example creates the two rectangles and rotates each rectangle in the timer handler. The first rectangle rotates around the top-left coordinates (`x=50, y=50`). Also, the second one rotates around the bottom-right coordinates (`x=100, y=100`).": "以下の例では二つの四角を作成し、各四角をタイマーのハンドラ内で回転させています。1つ目の四角は左上の座標（`x=50, y=50`）で回転させていて、2つ目の四角は右下の座標（`x=100, y=100`）で回転させています。",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _RectanglesOptions(TypedDict):\n    rectangle_1: ap.Rectangle\n    rectangle_2: ap.Rectangle\n\n\ndef on_timer(e: ap.TimerEvent, options: _RectanglesOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    x: ap.Int = ap.Int(50)\n    y: ap.Int = ap.Int(50)\n    rectangle_1: ap.Rectangle = options["rectangle_1"]\n    rotation: ap.Int = rectangle_1.get_rotation_around_point(x=x, y=y)\n    rotation += 1\n    rectangle_1.set_rotation_around_point(rotation=rotation, x=x, y=y)\n\n    rectangle_2: ap.Rectangle = options["rectangle_2"]\n    x = ap.Int(100)\n    y = ap.Int(100)\n    rotation = rectangle_2.get_rotation_around_point(x=x, y=y)\n    rotation += 1\n    rectangle_2.set_rotation_around_point(rotation=rotation, x=x, y=y)\n\n\nap.Stage(\n    stage_width=150,\n    stage_height=150,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"), alpha=0.5)\n\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\noptions: _RectanglesOptions = {"rectangle_1": rectangle_1, "rectangle_2": rectangle_2}\ntimer: ap.Timer = ap.Timer(on_timer, delay=ap.FPS.FPS_60, options=options)\ntimer.start()\n\nap.save_overall_html(dest_dir_path="graphics_base_rotation_around_point_basic_usage/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _RectanglesOptions(TypedDict):\n    rectangle_1: ap.Rectangle\n    rectangle_2: ap.Rectangle\n\n\ndef on_timer(e: ap.TimerEvent, options: _RectanglesOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : ap.TimerEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    x: ap.Int = ap.Int(50)\n    y: ap.Int = ap.Int(50)\n    rectangle_1: ap.Rectangle = options["rectangle_1"]\n    rotation: ap.Int = rectangle_1.get_rotation_around_point(x=x, y=y)\n    rotation += 1\n    rectangle_1.set_rotation_around_point(rotation=rotation, x=x, y=y)\n\n    rectangle_2: ap.Rectangle = options["rectangle_2"]\n    x = ap.Int(100)\n    y = ap.Int(100)\n    rotation = rectangle_2.get_rotation_around_point(x=x, y=y)\n    rotation += 1\n    rectangle_2.set_rotation_around_point(rotation=rotation, x=x, y=y)\n\n\nap.Stage(\n    stage_width=150,\n    stage_height=150,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"), alpha=0.5)\n\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\noptions: _RectanglesOptions = {"rectangle_1": rectangle_1, "rectangle_2": rectangle_2}\ntimer: ap.Timer = ap.Timer(on_timer, delay=ap.FPS.FPS_60, options=options)\ntimer.start()\n\nap.save_overall_html(dest_dir_path="graphics_base_rotation_around_point_basic_usage/")\n```',  # noqa
    ##################################################
    "## get_rotation_around_point API": "## get_rotation_around_point API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get a rotation value around the given coordinates.<hr>": "指定された座標を基準とした回転量を取得します。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `x`: Number": "- `x`: Number",
    ##################################################
    "  - X-coordinate.": "  - X座標。",
    ##################################################
    "- `y`: Number": "- `y`: Number",
    ##################################################
    "  - Y-coordinate.": "  - Y座標。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `rotation`: Int": "- `rotation`: Int",
    ##################################################
    "  - Rotation value around the given coordinates.": "  - 指定された座標基準による回転量。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> x: ap.Number = ap.Number(100)\n>>> y: ap.Number = ap.Number(100)\n>>> rectangle.set_rotation_around_point(rotation=ap.Int(45), x=x, y=y)\n>>> rectangle.get_rotation_around_point(x=x, y=y)\nInt(45)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> x: ap.Number = ap.Number(100)\n>>> y: ap.Number = ap.Number(100)\n>>> rectangle.set_rotation_around_point(rotation=ap.Int(45), x=x, y=y)\n>>> rectangle.get_rotation_around_point(x=x, y=y)\nInt(45)\n```',  # noqa
    ##################################################
    "## set_rotation_around_point API": "## set_rotation_around_point API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Update a rotation value around the given coordinates.<hr>": "指定された座標基準の回転量を更新します。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `rotation`: Int": "- `rotation`: Int",
    ##################################################
    "  - Rotation value to set.": "  - 設定する回転量。",
    ##################################################
    "- `x`: Number": "- `x`: Number",
    ##################################################
    "  - X-coordinate.": "  - X座標。",
    ##################################################
    "- `y`: Number": "- `y`: Number",
    ##################################################
    "  - Y-coordinate.": "  - Y座標。",
}



"""The class implementation for the outlined `all_out` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialAllOutOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `all_out` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M4 4v4l4-4zm12 0l4 4V4zm4 16v-4l-4 4zM4 20h4l-4-4zm15-8c0-3.87-3.13-7-7-7s-7 3.13-7 7 3.13 7 7 7 7-3.13 7-7zm-7 5c-2.76 0-5-2.24-5-5s2.24-5 5-5 5 2.24 5 5-2.24 5-5 5z"/></svg>'  # noqa



"""Mix-in class implementation for the relative value.
"""

from typing import Dict
from typing import Optional

from typing_extensions import final

from apysc._type.boolean import Boolean
from apysc._type.revert_mixin import RevertMixIn
from apysc._type.variable_name_suffix_attr_or_var_mixin import (
    VariableNameSuffixAttrOrVarMixIn,
)
from apysc._type.variable_name_suffix_mixin import VariableNameSuffixMixIn
from apysc._validation import arg_validation_decos


class RelativeMixIn(
    VariableNameSuffixAttrOrVarMixIn, RevertMixIn, VariableNameSuffixMixIn
):
    _relative: Boolean

    @final
    def _initialize_relative_if_not_initialized(self) -> None:
        """
        Initialize the _relative attribute if this instance
        does not initialize it yet.
        """
        if hasattr(self, "_relative"):
            return
        suffix: str = self._get_attr_or_variable_name_suffix(
            value_identifier="relative"
        )
        self._relative = Boolean(
            False,
            variable_name_suffix=suffix,
            skip_init_substitution_expression_appending=True,
        )

    @property
    def relative(self) -> Boolean:
        """
        Get a boolean value indicating whether a path data
        is relative or not.

        Returns
        -------
        relative : Boolean
            A boolean value indicating whether path data
            is relative or not.

        Examples
        --------
        >>> import apysc as ap
        >>> line_to: ap.PathLineTo = ap.PathLineTo(x=50, y=50, relative=False)
        >>> line_to.relative = ap.Boolean(True)
        >>> line_to.relative
        Boolean(True)
        """
        self._initialize_relative_if_not_initialized()
        return self._relative.copy()

    @relative.setter
    @arg_validation_decos.is_apysc_boolean(arg_position_index=1)
    def relative(self, value: Boolean) -> None:
        """
        Set a boolean value indicating whether path a path data
        is relative or not.

        Parameters
        ----------
        value : Boolean
            A boolean value indicating whether path data
            is relative or not.
        """
        self._initialize_relative_if_not_initialized()
        self._relative.value = value

    _relative_snapshots: Optional[Dict[str, bool]] = None

    def _make_snapshot(self, *, snapshot_name: str) -> None:
        """
        Make a value snapshot.

        Parameters
        ----------
        snapshot_name : str
            Target snapshot name.
        """
        self._initialize_relative_if_not_initialized()
        self._set_single_snapshot_val_to_dict(
            dict_name="_relative_snapshots",
            value=self._relative._value,
            snapshot_name=snapshot_name,
        )

    def _revert(self, *, snapshot_name: str) -> None:
        """
        Revert a value if a snapshot exists.

        Parameters
        ----------
        snapshot_name : str
            Target snapshot name.
        """
        self._initialize_relative_if_not_initialized()
        self._relative._value = self._get_snapshot_val_if_exists(
            current_value=self._relative._value,
            snapshot_dict=self._relative_snapshots,
            snapshot_name=snapshot_name,
        )



"""This module is for the translation mapping data of the
following document:

Document file: string_apply_max_num_of_decimal_places.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# String class apply_max_num_of_decimal_places interface": "# String クラスの apply_max_num_of_decimal_places インターフェイス",  # noqa
    ##################################################
    "This page explains the `String` class `apply_max_num_of_decimal_places` method interface.": "このページでは`String`クラスの`apply_max_num_of_decimal_places`メソッドのインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "The `apply_max_num_of_decimal_places` method applies the maximum number of decimal places to a string.": "`apply_max_num_of_decimal_places`メソッドは文字列に対して浮動小数点数の最大桁数の条件を反映します。",  # noqa
    ##################################################
    "For instance, if a string is `123.45678` and the maximum number of decimal places is `3`, this interface returns `123.456`.": "例えば、もし文字列が`123.45678`で小数点数の最大桁数が`3`だった場合、このインターフェイスは`123.456`の文字列を返却します。",  # noqa
    ##################################################
    "If a string is not in float format, this interface returns the original string.": "もしも文字列が浮動小数点数のフォーマットではない場合、このインターフェイスは元の文字列をそのまま返却します。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `apply_max_num_of_decimal_places` method requires the `max_num_of_decimal_places` (maximum number of decimal places, `int` or `Int` type) argument.": "`apply_max_num_of_decimal_places`は`max_num_of_decimal_places`（浮動小数点数の最大桁数、`int`もしくは`Int`型）引数の指定を必要とします。",  # noqa
    ##################################################
    "And this interface returns a new `String` instance.": "また、このインターフェイスは`String`型の新しいインスタンスを返却します。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=0,\n    stage_height=0,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\n\nstring = ap.String("123.456")\nstring = string.apply_max_num_of_decimal_places(max_num_of_decimal_places=1)\nap.assert_equal(string, "123.4")\n\n# If a string is not a `float` value, this interface returns\n# the original string.\nstring = ap.String("abc")\nstring = string.apply_max_num_of_decimal_places(max_num_of_decimal_places=1)\nap.assert_equal(string, "abc")\n\nap.save_overall_html(\n    dest_dir_path="string_apply_max_num_of_decimal_places_basic_usage_1/"\n)\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=0,\n    stage_height=0,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\n\nstring = ap.String("123.456")\nstring = string.apply_max_num_of_decimal_places(max_num_of_decimal_places=1)\nap.assert_equal(string, "123.4")\n\n# If a string is not a `float` value, this interface returns\n# the original string.\nstring = ap.String("abc")\nstring = string.apply_max_num_of_decimal_places(max_num_of_decimal_places=1)\nap.assert_equal(string, "abc")\n\nap.save_overall_html(\n    dest_dir_path="string_apply_max_num_of_decimal_places_basic_usage_1/"\n)\n```',  # noqa
    ##################################################
    "## apply_max_num_of_decimal_places API": "## apply_max_num_of_decimal_places API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Apply a maximum number of decimal places limit to this string.<hr>": "この文字列に浮動小数点数の最大桁数の設定を反映します。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `max_num_of_decimal_places`: Union[int, Int]": "- `max_num_of_decimal_places`: Union[int, Int]",  # noqa
    ##################################################
    "  - A maximum number of decimal places.": "  - 浮動小数点数の最大桁数。",
    ##################################################
    "- `variable_name_suffix`: str, optional": "- `variable_name_suffix`: str, optional",  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `string`: String": "- `string`: String",
    ##################################################
    "  - An applied string.": "  - 反映後の文字列。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> string = ap.String("123.456")\n>>> string = string.apply_max_num_of_decimal_places(max_num_of_decimal_places=1)\n>>> ap.assert_equal(string, "123.4")\n```': '```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> string = ap.String("123.456")\n>>> string = string.apply_max_num_of_decimal_places(max_num_of_decimal_places=1)\n>>> ap.assert_equal(string, "123.4")\n```',  # noqa
}



"""Class implementation for the ellipse width mix-in.
"""

from typing import Dict
from typing import Optional

from typing_extensions import final

from apysc._html.debug_mode import add_debug_info_setting
from apysc._type.attr_linking_mixin import AttrLinkingMixIn
from apysc._type.int import Int
from apysc._type.revert_mixin import RevertMixIn
from apysc._type.variable_name_mixin import VariableNameMixIn
from apysc._type.variable_name_suffix_attr_or_var_mixin import (
    VariableNameSuffixAttrOrVarMixIn,
)
from apysc._validation import arg_validation_decos


class EllipseWidthMixIn(
    VariableNameSuffixAttrOrVarMixIn,
    VariableNameMixIn,
    RevertMixIn,
    AttrLinkingMixIn,
):
    _ellipse_width: Int

    @final
    def _initialize_ellipse_width_if_not_initialized(self) -> None:
        """
        Initialize _ellipse_width attribute if this interface
        does not initialize it yet.
        """
        if hasattr(self, "_ellipse_width"):
            return
        suffix: str = self._get_attr_or_variable_name_suffix(
            value_identifier="ellipse_width"
        )
        self._ellipse_width = Int(
            0,
            variable_name_suffix=suffix,
            skip_init_substitution_expression_appending=True,
        )

        self._append_ellipse_width_attr_linking_setting()

    @final
    @add_debug_info_setting(module_name=__name__)
    def _append_ellipse_width_attr_linking_setting(self) -> None:
        """
        Append an ellipse-height attribute linking settings.
        """
        self._append_applying_new_attr_val_exp(
            new_attr=self._ellipse_width, attr_name="ellipse_width"
        )
        self._append_attr_to_linking_stack(
            attr=self._ellipse_width, attr_name="ellipse_width"
        )

    @property
    @add_debug_info_setting(module_name=__name__)
    def ellipse_width(self) -> Int:
        """
        Get ellipse width value.

        Returns
        -------
        ellipse_width : Int
            Ellipse width value.

        Examples
        --------
        >>> import apysc as ap
        >>> stage: ap.Stage = ap.Stage()
        >>> sprite: ap.Sprite = ap.Sprite()
        >>> sprite.graphics.begin_fill(color=ap.Color("#0af"), alpha=0.5)
        >>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(
        ...     x=50, y=50, width=50, height=50
        ... )
        >>> rectangle.ellipse_width = ap.Int(10)
        >>> rectangle.ellipse_height = ap.Int(15)
        >>> rectangle.ellipse_width
        Int(10)
        """
        from apysc._type import value_util

        self._initialize_ellipse_width_if_not_initialized()
        return value_util.get_copy(value=self._ellipse_width)

    @ellipse_width.setter
    @arg_validation_decos.is_apysc_num(arg_position_index=1)
    @add_debug_info_setting(module_name=__name__)
    def ellipse_width(self, value: Int) -> None:
        """
        Update ellipse width value.

        Parameters
        ----------
        value : int or Int
            Ellipse width value.
        """
        self._ellipse_width = value
        self._ellipse_width._append_incremental_calc_substitution_expression()
        self._append_ellipse_width_update_expression()

        self._append_ellipse_width_attr_linking_setting()

    @final
    @add_debug_info_setting(module_name=__name__)
    def _append_ellipse_width_update_expression(self) -> None:
        """
        Append ellipse width updating expression.
        """
        from apysc._expression import expression_data_util
        from apysc._type import value_util

        self._initialize_ellipse_width_if_not_initialized()
        width_value_str: str = value_util.get_value_str_for_expression(
            value=self._ellipse_width
        )
        if hasattr(self, "_ellipse_height"):
            height_value_str: str = value_util.get_value_str_for_expression(
                value=getattr(self, "_ellipse_height")
            )
        else:
            height_value_str = value_util.get_value_str_for_expression(value=0)
        expression: str = (
            f"{self.variable_name}.radius({width_value_str}, " f"{height_value_str});"
        )
        expression_data_util.append_js_expression(expression=expression)

    _ellipse_width_snapshots: Optional[Dict[str, int]] = None

    def _make_snapshot(self, *, snapshot_name: str) -> None:
        """
        Make the value's snapshot.

        Parameters
        ----------
        snapshot_name : str
            Target snapshot name.
        """
        self._initialize_ellipse_width_if_not_initialized()
        self._set_single_snapshot_val_to_dict(
            dict_name="_ellipse_width_snapshots",
            value=int(self._ellipse_width._value),
            snapshot_name=snapshot_name,
        )

    def _revert(self, *, snapshot_name: str) -> None:
        """
        Revert the value if the snapshot exists.

        Parameters
        ----------
        snapshot_name : str
            Target snapshot name.
        """
        self._ellipse_width._value = self._get_snapshot_val_if_exists(
            current_value=self._ellipse_width._value,
            snapshot_dict=self._ellipse_width_snapshots,
            snapshot_name=snapshot_name,
        )



"""The class implementation for the outlined `nat` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialNatOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `nat` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/></g><g><g><path d="M6.82,13H11v-2H6.82C6.4,9.84,5.3,9,4,9c-1.66,0-3,1.34-3,3s1.34,3,3,3C5.3,15,6.4,14.16,6.82,13z M4,13 c-0.55,0-1-0.45-1-1c0-0.55,0.45-1,1-1s1,0.45,1,1C5,12.55,4.55,13,4,13z"/><path d="M23,12l-4-3v2h-4.05C14.45,5.95,10.19,2,5,2v2c4.42,0,8,3.58,8,8s-3.58,8-8,8v2c5.19,0,9.45-3.95,9.95-9H19v2L23,12z"/></g></g></svg>'  # noqa



"""This module is the helper module for the flip interfaces.
"""

from enum import Enum

from apysc._type.boolean import Boolean


class Axis(Enum):
    X = "x"
    Y = "y"


def make_flip_update_expression(
    *,
    before_value: Boolean,
    after_value: Boolean,
    axis: Axis,
    interface_variable_name: str,
) -> str:
    """
    Make a flipping value updating expression.

    Parameters
    ----------
    before_value : Boolean
        Before updating flipping value.
    after_value : Boolean
        After updating flipping value.
    axis : Axis
        X or y axis value.
    interface_variable_name : str
        Interface instance variable name.

    Returns
    -------
    expression : str
        Made expression string.
    """
    from apysc._type import value_util

    before_value_str: str = value_util.get_value_str_for_expression(value=before_value)
    after_value_str: str = value_util.get_value_str_for_expression(value=after_value)
    expression: str = (
        f"if ({before_value_str}) {{"
        f'\n  {interface_variable_name}.flip("{axis.value}");'
        "\n}"
        f"\nif ({after_value_str}) {{"
        f'\n  {interface_variable_name}.flip("{axis.value}");'
        "\n}"
        f"\n{before_value_str} = {after_value_str};"
    )
    return expression



"""The class implementation for the outlined `settings_input_antenna` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialSettingsInputAntennaOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `settings_input_antenna` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M12 5c-3.87 0-7 3.13-7 7h2c0-2.76 2.24-5 5-5s5 2.24 5 5h2c0-3.87-3.13-7-7-7zm1 9.29c.88-.39 1.5-1.26 1.5-2.29 0-1.38-1.12-2.5-2.5-2.5S9.5 10.62 9.5 12c0 1.02.62 1.9 1.5 2.29v3.3L7.59 21 9 22.41l3-3 3 3L16.41 21 13 17.59v-3.3zM12 1C5.93 1 1 5.93 1 12h2c0-4.97 4.03-9 9-9s9 4.03 9 9h2c0-6.07-4.93-11-11-11z"/></svg>'  # noqa



"""The mix-in class implementation for the `use_hand_cursor` setting.
"""

from apysc._type.boolean import Boolean


class UseHandCursorMixIn:
    _use_hand_cursor: Boolean

    def _initialize_use_hand_cursor(self) -> None:
        """
        Initialize the `_use_hand_cursor` attribute if it hasn't been
        initialized yet.
        """
        from apysc._type.variable_name_suffix_utils import (
            get_attr_or_variable_name_suffix,
        )

        if hasattr(self, "_use_hand_cursor"):
            return

        suffix: str = get_attr_or_variable_name_suffix(
            instance=self, value_identifier="use_hand_cursor"
        )
        self._use_hand_cursor = Boolean(False, variable_name_suffix=suffix)

    @property
    def use_hand_cursor(self) -> Boolean:
        """
        Get a boolean value whether to use the hand cursor
        when the mouse pointer is over this instance.

        Returns
        -------
        use_hand_cursor : Boolean
            Whether to use the hand cursor or not.
        """
        self._initialize_use_hand_cursor()
        return self._use_hand_cursor.copy()

    @use_hand_cursor.setter
    def use_hand_cursor(self, value: Boolean) -> None:
        """
        Set a boolean value whether to use the hand cursor
        when the mouse pointer is over this instance.

        Parameters
        ----------
        value : Boolean
            Boolean value to set.
        """
        from apysc._branch._else import Else
        from apysc._branch._if import If
        from apysc._display.css_interface import CssInterface
        from apysc._validation.display_validation import validate_css_interface

        self._initialize_use_hand_cursor()
        self._use_hand_cursor.value = value
        self_instance: CssInterface = validate_css_interface(instance=self)
        with If(self._use_hand_cursor):
            self_instance.set_css(name="cursor", value="pointer")
        with Else():
            self_instance.set_css(name="cursor", value="auto")



"""The class implementation for the `next_week` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialNextWeekIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `next_week` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24" x="0"/></g><g><g><g><path d="M20,7h-4V5c0-0.55-0.22-1.05-0.59-1.41C15.05,3.22,14.55,3,14,3h-4C8.9,3,8,3.9,8,5v2H4C2.9,7,2,7.9,2,9v11 c0,1.1,0.9,2,2,2h16c1.1,0,2-0.9,2-2V9C22,7.9,21.1,7,20,7z M10,5h4v2h-4V5z M11,18.5l-1-1l3-3l-3-3l1-1l4,4L11,18.5z"/></g></g></g></svg>'  # noqa



"""The class implementation for the `cancel_schedule_send` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialCancelScheduleSendIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `cancel_schedule_send` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/></g><g><g><path d="M16.5,9c-0.42,0-0.83,0.04-1.24,0.11L1.01,3L1,10l9,2l-9,2l0.01,7l8.07-3.46C9.59,21.19,12.71,24,16.5,24 c4.14,0,7.5-3.36,7.5-7.5S20.64,9,16.5,9z M16.5,22c-3.03,0-5.5-2.47-5.5-5.5s2.47-5.5,5.5-5.5s5.5,2.47,5.5,5.5S19.53,22,16.5,22 z"/><polygon points="18.27,14.03 16.5,15.79 14.73,14.03 14.03,14.73 15.79,16.5 14.03,18.27 14.73,18.97 16.5,17.21 18.27,18.97 18.97,18.27 17.21,16.5 18.97,14.73"/></g></g></svg>'  # noqa



"""Mix-in class implementation for the `_set_initial_border_thickness`
method.
"""

from typing import Union

from typing_extensions import final

from apysc._html.debug_mode import add_debug_info_setting
from apysc._type.int import Int
from apysc._validation import arg_validation_decos


class SetInitialBorderThicknessMixIn:
    _border_thickness: Int

    @final
    @arg_validation_decos.is_integer(arg_position_index=1, optional=False)
    @arg_validation_decos.num_is_gte_zero(arg_position_index=1, optional=False)
    @arg_validation_decos.is_builtin_string(arg_position_index=2, optional=False)
    @add_debug_info_setting(module_name=__name__)
    def _set_initial_border_thickness(
        self,
        *,
        border_thickness: Union[int, Int],
        variable_name_suffix: str = "",
    ) -> None:
        """
        Set a chart's initial border thickness.

        Parameters
        ----------
        border_thickness : Union[int, Int]
            A chart's border thickness.
        variable_name_suffix : str, optional
            A JavaScript variable name suffix string.
            This setting is sometimes useful for JavaScript debugging.
        """
        if not isinstance(border_thickness, Int):
            border_thickness_: Int = Int(
                border_thickness, variable_name_suffix=variable_name_suffix
            )
        else:
            border_thickness_ = border_thickness
        self._border_thickness = border_thickness_



"""The class implementation for the `gavel` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialGavelIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `gavel` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24" x="0"/></g><g><g><rect height="20" transform="matrix(0.7075 -0.7067 0.7067 0.7075 -5.6854 13.7194)" width="4" x="11.73" y="3.73"/><rect height="8" transform="matrix(0.707 -0.7072 0.7072 0.707 0.3157 11.246)" width="4" x="11.73" y="1.24"/><rect height="8" transform="matrix(0.7071 -0.7071 0.7071 0.7071 -8.1722 7.7256)" width="4" x="3.24" y="9.73"/><rect height="2" width="12" x="1" y="21"/></g></g></svg>'  # noqa



"""The class implementation for the outlined `next_plan` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialNextPlanOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `next_plan` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/></g><g><g><path d="M12,2C6.48,2,2,6.48,2,12c0,5.52,4.48,10,10,10s10-4.48,10-10C22,6.48,17.52,2,12,2z M12,20c-4.42,0-8-3.58-8-8 s3.58-8,8-8s8,3.58,8,8S16.42,20,12,20z"/><path d="M15.97,11.03C14.87,9.79,13.28,9,11.5,9c-2.82,0-5.18,1.95-5.82,4.56l0.96,0.32C7.15,11.66,9.13,10,11.5,10 c1.51,0,2.85,0.68,3.76,1.74L13,14h5V9L15.97,11.03z"/></g></g></svg>'  # noqa



"""This module is for the translation mapping data of the
following document:

Document file: text_align_last.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# text_align_last property": "# text_align_last 属性",
    ##################################################
    "This page explains the text-related `text_align_last` property.": "このページではテキスト関係の`text_align_last`属性について説明します。",  # noqa
    ##################################################
    "## What property is this?": "## 属性の概要",
    ##################################################
    "The `text_align_last` property updates or gets the text last line's alignment setting.": "`text_align_last`属性では最終行の行揃えの設定の更新もしくは取得を行えます。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The getter and setter interfaces' type becomes an `ap.CssTextAlignLast` enum value.": "getterとsetterの各インターフェイスの型は`ap.CssTextAlignLast`のenumの値となります。",  # noqa
    ##################################################
    "The acceptable enum values are as follows:": "指定できるenumの値は以下の通りです:",
    ##################################################
    "- `CssTextAlignLast.AUTO` (default)": "- `CssTextAlignLast.AUTO` （デフォルト）",
    ##################################################
    "- `CssTextAlignLast.LEFT`": "- `CssTextAlignLast.LEFT`",
    ##################################################
    "- `CssTextAlignLast.CENTER`": "- `CssTextAlignLast.CENTER`",
    ##################################################
    "- `CssTextAlignLast.RIGHT`": "- `CssTextAlignLast.RIGHT`",
    ##################################################
    "- `CssTextAlignLast.JUSTIFY`": "- `CssTextAlignLast.JUSTIFY`",
    ##################################################
    "## Example of CssTextAlignLast.AUTO": "## CssTextAlignLast.AUTOの例",
    ##################################################
    "Notes: This setting is a default setting.": "特記事項: この設定はデフォルトの設定です。",
    ##################################################
    "The `CssTextAlignLast.AUTO` setting inherits the `text_align` setting.": "`CssTextAlignLast.AUTO`設定（挙動）は`text_align`の設定を継承します。",  # noqa
    ##################################################
    "For example, if the `text_align` setting is the `CssTextAlign.CENTER`, the `text_align_last` property also behaves as the center align.": "例えば、もし`text_align`設定が`CssTextAlign.CENTER`の場合には`text_align_last`属性も中央寄せとして振る舞います。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=350,\n    stage_height=170,\n    stage_elem_id="stage",\n)\nmulti_line_text: ap.MultiLineText = ap.MultiLineText(\n    text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "\n    "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "\n    "Ut enim ad minim veniam",\n    width=300,\n    font_size=16,\n    fill_color=ap.Color("#00aaff"),\n    x=25,\n    y=25,\n)\nmulti_line_text.text_align = ap.CssTextAlign.CENTER\nmulti_line_text.text_align_last = ap.CssTextAlignLast.AUTO\n\nap.save_overall_html(dest_dir_path="./css_text_align_last_auto/")\n```': '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=350,\n    stage_height=170,\n    stage_elem_id="stage",\n)\nmulti_line_text: ap.MultiLineText = ap.MultiLineText(\n    text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "\n    "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "\n    "Ut enim ad minim veniam",\n    width=300,\n    font_size=16,\n    fill_color=ap.Color("#00aaff"),\n    x=25,\n    y=25,\n)\nmulti_line_text.text_align = ap.CssTextAlign.CENTER\nmulti_line_text.text_align_last = ap.CssTextAlignLast.AUTO\n\nap.save_overall_html(dest_dir_path="./css_text_align_last_auto/")\n```',  # noqa
    ##################################################
    "## Example of CssTextAlignLast.LEFT": "## CssTextAlignLast.LEFTの例",
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=350,\n    stage_height=170,\n    stage_elem_id="stage",\n)\nmulti_line_text: ap.MultiLineText = ap.MultiLineText(\n    text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "\n    "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "\n    "Ut enim ad minim veniam",\n    width=300,\n    font_size=16,\n    fill_color=ap.Color("#00aaff"),\n    x=25,\n    y=25,\n)\nmulti_line_text.text_align = ap.CssTextAlign.JUSTIFY\nmulti_line_text.text_align_last = ap.CssTextAlignLast.LEFT\n\nap.save_overall_html(dest_dir_path="./css_text_align_last_left/")\n```': '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=350,\n    stage_height=170,\n    stage_elem_id="stage",\n)\nmulti_line_text: ap.MultiLineText = ap.MultiLineText(\n    text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "\n    "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "\n    "Ut enim ad minim veniam",\n    width=300,\n    font_size=16,\n    fill_color=ap.Color("#00aaff"),\n    x=25,\n    y=25,\n)\nmulti_line_text.text_align = ap.CssTextAlign.JUSTIFY\nmulti_line_text.text_align_last = ap.CssTextAlignLast.LEFT\n\nap.save_overall_html(dest_dir_path="./css_text_align_last_left/")\n```',  # noqa
    ##################################################
    "## Example of CssTextAlignLast.CENTER": "## CssTextAlignLast.CENTERの例",
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=350,\n    stage_height=170,\n    stage_elem_id="stage",\n)\nmulti_line_text: ap.MultiLineText = ap.MultiLineText(\n    text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "\n    "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "\n    "Ut enim ad minim veniam",\n    width=300,\n    font_size=16,\n    fill_color=ap.Color("#00aaff"),\n    x=25,\n    y=25,\n)\nmulti_line_text.text_align = ap.CssTextAlign.JUSTIFY\nmulti_line_text.text_align_last = ap.CssTextAlignLast.CENTER\n\nap.save_overall_html(dest_dir_path="./css_text_align_last_center/")\n```': '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=350,\n    stage_height=170,\n    stage_elem_id="stage",\n)\nmulti_line_text: ap.MultiLineText = ap.MultiLineText(\n    text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "\n    "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "\n    "Ut enim ad minim veniam",\n    width=300,\n    font_size=16,\n    fill_color=ap.Color("#00aaff"),\n    x=25,\n    y=25,\n)\nmulti_line_text.text_align = ap.CssTextAlign.JUSTIFY\nmulti_line_text.text_align_last = ap.CssTextAlignLast.CENTER\n\nap.save_overall_html(dest_dir_path="./css_text_align_last_center/")\n```',  # noqa
    ##################################################
    "## Example of CssTextAlignLast.RIGHT": "## CssTextAlignLast.RIGHTの例",
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=350,\n    stage_height=170,\n    stage_elem_id="stage",\n)\nmulti_line_text: ap.MultiLineText = ap.MultiLineText(\n    text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "\n    "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "\n    "Ut enim ad minim veniam",\n    width=300,\n    font_size=16,\n    fill_color=ap.Color("#00aaff"),\n    x=25,\n    y=25,\n)\nmulti_line_text.text_align = ap.CssTextAlign.JUSTIFY\nmulti_line_text.text_align_last = ap.CssTextAlignLast.RIGHT\n\nap.save_overall_html(dest_dir_path="./css_text_align_last_right/")\n```': '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=350,\n    stage_height=170,\n    stage_elem_id="stage",\n)\nmulti_line_text: ap.MultiLineText = ap.MultiLineText(\n    text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "\n    "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "\n    "Ut enim ad minim veniam",\n    width=300,\n    font_size=16,\n    fill_color=ap.Color("#00aaff"),\n    x=25,\n    y=25,\n)\nmulti_line_text.text_align = ap.CssTextAlign.JUSTIFY\nmulti_line_text.text_align_last = ap.CssTextAlignLast.RIGHT\n\nap.save_overall_html(dest_dir_path="./css_text_align_last_right/")\n```',  # noqa
    ##################################################
    "## Example of CssTextAlignLast.JUSTIFY": "## CssTextAlignLast.JUSTIFYの例",
    ##################################################
    "Notes: This enum setting justifies the last line text evenly.": "特記事項: このenumの設定は最終行のテキストを均等に行揃えします。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=350,\n    stage_height=170,\n    stage_elem_id="stage",\n)\nmulti_line_text: ap.MultiLineText = ap.MultiLineText(\n    text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "\n    "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "\n    "Ut enim ad minim veniam",\n    width=300,\n    font_size=16,\n    fill_color=ap.Color("#00aaff"),\n    x=25,\n    y=25,\n)\nmulti_line_text.text_align = ap.CssTextAlign.JUSTIFY\nmulti_line_text.text_align_last = ap.CssTextAlignLast.JUSTIFY\n\nap.save_overall_html(dest_dir_path="./css_text_align_last_justify/")\n```': '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=350,\n    stage_height=170,\n    stage_elem_id="stage",\n)\nmulti_line_text: ap.MultiLineText = ap.MultiLineText(\n    text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "\n    "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "\n    "Ut enim ad minim veniam",\n    width=300,\n    font_size=16,\n    fill_color=ap.Color("#00aaff"),\n    x=25,\n    y=25,\n)\nmulti_line_text.text_align = ap.CssTextAlign.JUSTIFY\nmulti_line_text.text_align_last = ap.CssTextAlignLast.JUSTIFY\n\nap.save_overall_html(dest_dir_path="./css_text_align_last_justify/")\n```',  # noqa
    ##################################################
    "## text_align_last property API": "## text_align_last 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get a text-align-last value.<hr>": "text-align-last属性の値を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `text_align_last`: CssTextAlignLast": "- `text_align_last`: CssTextAlignLast",
    ##################################################
    "  - A text-align-last value.": "  - text-align-last属性の値。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     background_color=ap.Color("#333"),\n...     stage_width=350,\n...     stage_height=170,\n...     stage_elem_id="stage",\n... )\n>>> multi_line_text: ap.MultiLineText = ap.MultiLineText(\n...     text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "\n...     "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "\n...     "Ut enim ad minim veniam",\n...     width=300,\n...     font_size=16,\n...     fill_color=ap.Color("#00aaff"),\n...     x=25,\n...     y=25,\n... )\n>>> multi_line_text.text_align = ap.CssTextAlign.JUSTIFY\n>>> multi_line_text.text_align_last = ap.CssTextAlignLast.RIGHT\n>>> assert multi_line_text.text_align_last == ap.CssTextAlignLast.RIGHT\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     background_color=ap.Color("#333"),\n...     stage_width=350,\n...     stage_height=170,\n...     stage_elem_id="stage",\n... )\n>>> multi_line_text: ap.MultiLineText = ap.MultiLineText(\n...     text="Lorem ipsum dolor sit amet, consectetur adipiscing elit, "\n...     "sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. "\n...     "Ut enim ad minim veniam",\n...     width=300,\n...     font_size=16,\n...     fill_color=ap.Color("#00aaff"),\n...     x=25,\n...     y=25,\n... )\n>>> multi_line_text.text_align = ap.CssTextAlign.JUSTIFY\n>>> multi_line_text.text_align_last = ap.CssTextAlignLast.RIGHT\n>>> assert multi_line_text.text_align_last == ap.CssTextAlignLast.RIGHT\n```',  # noqa
}
